# Changelog

## [0.2.7] - 2022-11-18

- PEP 518-compliant with `pyproject.toml` and `build-system`

## [0.2.6] - 2021-12-05

- Use `oldest-supported-numpy` package when building wheels for greatest compatibility support

## [0.2.5] - 2021-12-05

- Build wheels for Mac ARM architectures

## [0.2.4] - 2021-12-05

- Build wheels for Python 3.10

## [0.2.3] - 2021-11-08

- Fix ssize_t on Windows (#24), thanks @davidbrochart !

## [0.2.2] - 2020-10-19

- Fix accidentally not including the last fix in 0.2.1

## [0.2.1] - 2020-10-19

- Fixes to allow for a Conda package on Windows

## [0.2.0] - 2020-10-10

- Update docs with instructions for saving mesh
- Add `rescale_positions` util

## [0.1.0] - 2020-10-05

- Initial release

## [0.0.1], [0.0.2] - 2020-10-03

- Test releases on PyPI to test auto-building wheels with cibuildwheel
